summaryrefslogtreecommitdiff
path: root/jn.c
diff options
context:
space:
mode:
authorvlefevre <vlefevre@280ebfd0-de03-0410-8827-d642c229c3f4>2007-04-02 15:32:00 +0000
committervlefevre <vlefevre@280ebfd0-de03-0410-8827-d642c229c3f4>2007-04-02 15:32:00 +0000
commitecf36b53bf67014953b0feeecaa338df17ee71a9 (patch)
tree652ff99b6f5f62892aca90194a64e7ef94755d37 /jn.c
parent4662a8f3a8a82b694d45c2ce41aca61927e3be92 (diff)
downloadmpfr-ecf36b53bf67014953b0feeecaa338df17ee71a9.tar.gz
Changed mpfr_{jn,yn}_si (mpfr_t res, mpfr_t x, long n, ...) into
mpfr_{jn,yn} (mpfr_t res, long n, mpfr_t x, ...), as discussed by mail; fixed a typo in mpfr.texi in mpfr_{y0,y1,yn} description. git-svn-id: svn://scm.gforge.inria.fr/svn/mpfr/trunk@4405 280ebfd0-de03-0410-8827-d642c229c3f4
Diffstat (limited to 'jn.c')
-rw-r--r--jn.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/jn.c b/jn.c
index e78c00ca8..d0100b0cf 100644
--- a/jn.c
+++ b/jn.c
@@ -1,4 +1,4 @@
/* mpfr_j0, mpfr_j1, mpfr_jn_si -- Bessel functions of 1st kind, integer order.
http://www.opengroup.org/onlinepubs/009695399/functions/j0.html
Copyright 2007 Free Software Foundation, Inc.
@@ -29,17 +29,17 @@ MA 02110-1301, USA. */
int
mpfr_j0 (mpfr_ptr res, mpfr_srcptr z, mp_rnd_t r)
{
- return mpfr_jn_si (res, z, 0, r);
+ return mpfr_jn (res, 0, z, r);
}
int
mpfr_j1 (mpfr_ptr res, mpfr_srcptr z, mp_rnd_t r)
{
- return mpfr_jn_si (res, z, 1, r);
+ return mpfr_jn (res, 1, z, r);
}
int
-mpfr_jn_si (mpfr_ptr res, mpfr_srcptr z, long n, mp_rnd_t r)
+mpfr_jn (mpfr_ptr res, long n, mpfr_srcptr z, mp_rnd_t r)
{
int inex;
unsigned long absn;
@@ -109,7 +109,7 @@ mpfr_jn_si (mpfr_ptr res, mpfr_srcptr z, long n, mp_rnd_t r)
: MPFR_SIGN_POS);
}
}
-
+
mpfr_init (s);
mpfr_init (t);
@@ -1,4 +1,4 @@
-/* mpfr_j0, mpfr_j1, mpfr_jn_si -- Bessel functions of 1st kind, integer order.
+/* mpfr_j0, mpfr_j1, mpfr_jn -- Bessel functions of 1st kind, integer order.
http://www.opengroup.org/onlinepubs/009695399/functions/j0.html
Copyright 2007 Free Software Foundation, Inc.